/*
** petopt.h - Command line argument parser header file
**
** Copyright (c) 1999 Peter Eriksson <pen@lysator.liu.se>
**
** This program is free software; you can redistribute it and/or
** modify it as you wish - as long as you don't claim that you wrote
** it.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

#ifndef PETOPT_H
#define PETOPT_H

#define POF_NONE 0x00
#define POF_INT  0x0001	 /* Argument is a number */
#define POF_STR  0x0002	 /* Argument is a string */
#define POF_OPT  0x0100	 /* Argument is optional */

/* Error returns */
#define POE_EOF     -1

#define POE_OPTION  -2 /* Invalid option */
#define POE_MULTI   -3 /* Option is not unique */
#define POE_MISSING -4 /* Required argument to option is missing */
#define POE_INVALID -5 /* Invalid argument to option */

typedef struct petopt_option
{
    int s;      /* Short option character */
    int f;      /* Argument flags */
    char *l;    /* Long option name */
    char *h;	/* Help/usage string */
} PETOPTS;


typedef struct petopt
{
    unsigned int flags;
    int (*parse)(struct petopt *pp, int opt, char *arg);
    int (*errprint)(struct petopt *pp, int err, char **, int i, int s);
    PETOPTS *pov;
} PETOPT;


struct petopt_parseinfo
{
    unsigned int ai;
    unsigned int ci;
    int argc;
    char **argv;
    struct petopt_option *pov;
};



extern int
petopt_parse(PETOPT *ap,
	     int argc,
	     char *argv[],
	     int *i);

extern int
petopt_usage(PETOPT *ap,
	     FILE *fp);

#endif
